@@ -1,7 +1,7 @@
 """Test algo functionality."""
 import inspect
 from .errors import TestError
-from .tabular import test_tabular
+from .tabular import test_tabular_algo
 from ..base.algo import Algo
 from ..base.tabular import TabularClassificationAutoML, TabularRegressionAutoML
 
@@ -19,7 +19,7 @@ def test_algo(algo, output_dir, timeout = 100, nan_fraction = 0.1):
         None.
     """
     if issubclass(algo, TabularClassificationAutoML) or issubclass(algo, TabularRegressionAutoML):
-        return test_tabular(algo, output_dir, timeout, nan_fraction)
+        return test_tabular_algo(algo, output_dir, timeout, nan_fraction)
     else:
         raise TestError('invalid algo class')
 
