@@ -145,7 +145,17 @@ class CategoricalListTransformer(BaseEstimator, TransformerMixin):
         return np.concatenate(transforms, axis=1) 
 
 class BinaryTransformer(BaseEstimator, TransformerMixin):
-    """Converts binary categoricals to bools."""
+    """
+    Converts binary categoricals to bools.
+
+    Args:
+        nan_unknowns: replaces unknown category with nan.
+    """
+    def __init__(self, nan_unknowns = True):
+        if not isinstance(nan_unknowns, bool):
+            raise TypeError('nan_unkonwns must be bool')
+        self._nan_unknowns = nan_unknowns
+
     def fit(self, X, y = None):
         """
         Fits transformer to X.
@@ -179,9 +189,56 @@ class BinaryTransformer(BaseEstimator, TransformerMixin):
         for col, s in X.items():
             cat = self.categories[col]
             binary = s == cat[1]
+            if self._nan_unknowns:
+                binary[~s.isin(cat)] = np.nan
+
             transforms.append(binary)
         return pd.concat(transforms, axis=1).mask(pd.isnull(X)).astype('O')
 
+class CategoricalImputer(BaseEstimator, TransformerMixin):
+    """
+    Imputes categoricals with constant and transforms unknown as missing.
+
+    Args:
+        fill_value: value to replace nulls with.
+    """
+    def __init__(self, fill_value):
+        self._fill_value = fill_value
+
+    def fit(self, X, y = None):
+        """
+        Fits transformer to X.
+
+        Args:
+            X: DataFrame.
+            y: optional.
+
+        Returns:
+            self.
+        """
+        self.categories = dict()
+        for col, s in X.items():
+            self.categories[col] = set(s.dropna().unique())
+        return self
+
+    def transform(self, X):
+        """
+        Replaces missing and unknowns with fill_value.
+
+        Args:
+            X: DataFrame.
+
+        Returns:
+            DataFrame.
+        """
+        X = X.copy()
+        idx_unknowns = []
+        for col, s in X.items():
+            idx_unknowns.append(~s.isin(self.categories[col]))
+
+        X[pd.concat(idx_unknowns, axis=1) | pd.isnull(X)] = self._fill_value
+        return X
+
 class ColumnTransformer(BaseEstimator, TransformerMixin):
     """ColumnTransformer specifically for DataFrame.
 
